@@ -8,7 +8,6 @@ from tsdoc0.python.model import Model
 from tsdoc0.python.segment import Segment
 from tsdoc0.python.solution_code import SolutionCode
 from tsdoc0.python.utils import repr_parent
-from typing import cast
 from typing import Final
 from typing import Optional
 
@@ -36,8 +35,6 @@ class QuestionAbstract(Segment):
 
         for segment in segments_next:
             if type(segment) is CommentAbstract:
-                segment = cast(CommentAbstract, segment)
-
                 question_abstract.answer = AnswerAbstract(
                     parent=question_abstract,
                     indentation=question_abstract.indentation,
