@@ -8,7 +8,6 @@ from tsdoc0.python.segment import Segment
 from tsdoc0.python.solution_code import SolutionCode
 from tsdoc0.python.solution_shape import SolutionShape
 from tsdoc0.python.utils import repr_parent
-from typing import cast
 from typing import Final
 from typing import Optional
 
@@ -36,8 +35,6 @@ class QuestionShape(Segment):
 
         for segment in segments_next:
             if type(segment) is SolutionShape:
-                segment = cast(SolutionShape, segment)
-
                 question_shape.answer = AnswerShape(
                     parent=question_shape,
                     indentation=question_shape.indentation,
