@@ -5,14 +5,13 @@ from tsdoc0.python.utils import repr_parent
 from typing import Final
 from typing import Iterable
 from typing import Optional
-from typing import Tuple
 
 import attr
 
 
 # This converter wrapper-function is used because of a bug with the mypy-attrs plugin.
 # https://github.com/python/mypy/issues/8389
-def _tuple(iterable: Iterable[VocabularyTerm]) -> Tuple[VocabularyTerm, ...]:
+def _tuple(iterable: Iterable[VocabularyTerm]) -> tuple[VocabularyTerm, ...]:
     return tuple(iterable)
 
 
@@ -20,4 +19,4 @@ def _tuple(iterable: Iterable[VocabularyTerm]) -> Tuple[VocabularyTerm, ...]:
 class Vocabulary(Segment):
     parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
-    terms: Final[Tuple[VocabularyTerm, ...]] = attr.ib(converter=_tuple)
+    terms: Final[tuple[VocabularyTerm, ...]] = attr.ib(converter=_tuple)
